Torin

Struct Torin 

pub struct Torin<Key: NodeKey> {
    pub results: FxHashMap<Key, LayoutNode>,
    pub dirty: FxHashMap<Key, DirtyReason>,
    pub root_node_candidate: RootNodeCandidate<Key>,
}

Fields

results: FxHashMap<Key, LayoutNode>

Layout results of the registered Nodes

dirty: FxHashMap<Key, DirtyReason>

Invalid registered nodes since previous layout measurement

root_node_candidate: RootNodeCandidate<Key>

Best Root node candidate from where to start measuringg

Implementations

Source

impl<Key: NodeKey> Torin<Key>

pub fn new() -> Self

Create a new Layout

pub fn size(&self) -> usize

pub fn clear_dirty(&mut self)

Clear the dirty nodes buffer

pub fn reset(&mut self)

Reset the layout

pub fn get_dirty_nodes(&self) -> &FxHashMap<Key, DirtyReason>

Read the HashSet of dirty nodes

pub fn raw_remove(&mut self, node_id: Key)

Remove a Node’s result and data

pub fn remove( &mut self, node_id: Key, tree_adapter: &mut impl TreeAdapter<Key>, invalidate_parent: bool, )

Remove a Node from the layout

Panics

Might panic if the parent is not found.

pub fn safe_invalidate(&mut self, node_id: Key)

Safely mark as dirty a Node, with no reason.

pub fn invalidate(&mut self, node_id: Key)

Mark as dirty a Node, with no reason.

pub fn invalidate_with_reason(&mut self, node_id: Key, reason: DirtyReason)

Mark as dirty a Node, with a reason.

pub fn check_dirty_dependants( &mut self, node_id: Key, reason: DirtyReason, tree_adapter: &mut impl TreeAdapter<Key>, ignore: bool, )

pub fn get_root_candidate(&self) -> RootNodeCandidate<Key>

Get the Root Node candidate

pub fn find_best_root(&mut self, tree_adapter: &mut impl TreeAdapter<Key>)

Find the best root Node from where to start measuringg

pub fn measure( &mut self, suggested_root_id: Key, root_area: Area, measurer: &mut Option<impl LayoutMeasurer<Key>>, tree_adapter: &mut impl TreeAdapter<Key>, )

Measure dirty Nodes

Panics

Might panic if the final root node is not found.

pub fn get(&self, node_id: &Key) -> Option<&LayoutNode>

Get a reference to LayoutNode of a Node

pub fn get_mut(&mut self, node_id: &Key) -> Option<&mut LayoutNode>

Get a mutable reference to LayoutNode of a Node

pub fn cache_node(&mut self, node_id: Key, layout_node: LayoutNode)

Cache a Node’s LayoutNode